@@ -470,7 +470,8 @@ async def _mikrotik_probe(host,
                             raise
                         except Exception as err:
                             last_err = err
-                            return None
+                            await mikrotik_api.close()
+                            break
                         client = mikrotik_api
                         return client
                 except (MikrotikApiError, OSError, asyncio.TimeoutError) as err:
